@@ -7,6 +7,8 @@
  *   (at your option) any later version.                                   *
  ***************************************************************************/
 
+// clazy:excludeall=qstring-allocations
+
 #include <QtTest>
 
 #include "../core/document.h"
@@ -20,7 +22,7 @@ class SearchFinishedReceiver : public QObject
 {
     Q_OBJECT
 
-    private slots:
+    public slots:
         void searchFinished(int id, Okular::Document::SearchStatus status)
         {
             m_id = id;
@@ -170,7 +172,7 @@ void SearchTest::test311232()
     SearchFinishedReceiver receiver;
     QSignalSpy spy(&d, &Okular::Document::searchFinished);
 
-    QObject::connect(&d, SIGNAL(searchFinished(int,Okular::Document::SearchStatus)), &receiver, SLOT(searchFinished(int,Okular::Document::SearchStatus)));
+    QObject::connect(&d, &Okular::Document::searchFinished, &receiver, &SearchFinishedReceiver::searchFinished);
     
     const QString testFile = QStringLiteral(KDESRCDIR "data/file1.pdf");
     QMimeDatabase db;
@@ -240,7 +242,7 @@ void SearchTest::testDottedI()
 
     //In the future it would be nice to add support for matching "İ"<->"i" and "I"<->"ı" in case-insensitive
     //mode as well (QString::compare does not match them, at least in non-Turkish locales, since it follows
-    //the Unicode case-folding rules http://www.unicode.org/Public/6.2.0/ucd/CaseFolding.txt).
+    //the Unicode case-folding rules https://www.unicode.org/Public/6.2.0/ucd/CaseFolding.txt).
 
     QVector<QString> text;
     text << QStringLiteral("İ");
