@@ -20,8 +20,8 @@ class DlgAccessibility : public QWidget
     Q_OBJECT
 
     public:
-        explicit DlgAccessibility( QWidget * parent = Q_NULLPTR );
-        ~DlgAccessibility();
+        explicit DlgAccessibility( QWidget * parent = nullptr );
+        ~DlgAccessibility() override;
 
     private Q_SLOTS:
         void slotColorMode( int mode );
