@@ -151,16 +151,16 @@ QDomElement AnnotationUtils::findChildElement( const QDomNode & parentNode,
     return QDomElement();
 }
 
-QRect AnnotationUtils::annotationGeometry( const Annotation * ann,
-    double scaledWidth, double scaledHeight )
+QRect AnnotationUtils::annotationGeometry( const Annotation * annotation,
+    double scaleX, double scaleY )
 {
-    const QRect rect = ann->transformedBoundingRectangle().geometry( (int)scaledWidth, (int)scaledHeight );
-    if ( ann->subType() == Annotation::AText && ( ( (TextAnnotation*)ann )->textType() == TextAnnotation::Linked ) )
+    const QRect rect = annotation->transformedBoundingRectangle().geometry( (int)scaleX, (int)scaleY );
+    if ( annotation->subType() == Annotation::AText && ( ( (TextAnnotation*)annotation )->textType() == TextAnnotation::Linked ) )
     {
         // To be honest i have no clue of why the 24,24 is here, maybe to make sure it's not too small?
         // But why only for linked text?
-        const QRect rect24 = QRect( (int)( ann->transformedBoundingRectangle().left * scaledWidth ),
-                                    (int)( ann->transformedBoundingRectangle().top * scaledHeight ), 24, 24 );
+        const QRect rect24 = QRect( (int)( annotation->transformedBoundingRectangle().left * scaleX ),
+                                    (int)( annotation->transformedBoundingRectangle().top * scaleY ), 24, 24 );
         return rect24.united(rect);
     }
 
@@ -168,6 +168,10 @@ QRect AnnotationUtils::annotationGeometry( const Annotation * ann,
 }
 //END AnnotationUtils implementation
 
+AnnotationProxy::AnnotationProxy()
+{
+}
+
 AnnotationProxy::~AnnotationProxy()
 {
 }
@@ -510,10 +514,10 @@ Annotation::Annotation( AnnotationPrivate &dd )
 {
 }
 
-Annotation::Annotation( AnnotationPrivate &dd, const QDomNode & annNode )
+Annotation::Annotation( AnnotationPrivate &dd, const QDomNode & description )
     : d_ptr( &dd )
 {
-    d_ptr->setAnnotationProperties( annNode );
+    d_ptr->setAnnotationProperties( description );
 }
 
 Annotation::~Annotation()
@@ -855,7 +859,7 @@ void Annotation::setAnnotationProperties( const QDomNode& node )
     d_ptr->transform( d_ptr->m_page->rotationMatrix() );
 }
 
-double AnnotationPrivate::distanceSqr( double x, double y, double xScale, double yScale )
+double AnnotationPrivate::distanceSqr( double x, double y, double xScale, double yScale ) const
 {
     return m_transformedBoundary.distanceSqr( x, y, xScale, yScale );
 }
@@ -1043,8 +1047,8 @@ TextAnnotation::TextAnnotation()
 {
 }
 
-TextAnnotation::TextAnnotation( const QDomNode & node )
-    : Annotation( *new TextAnnotationPrivate(), node )
+TextAnnotation::TextAnnotation( const QDomNode & description )
+    : Annotation( *new TextAnnotationPrivate(), description )
 {
 }
 
@@ -1198,8 +1202,8 @@ void TextAnnotationPrivate::transform( const QTransform &matrix )
 {
     AnnotationPrivate::transform( matrix );
 
-    for ( int i = 0; i < 3; ++i ) {
-       m_transformedInplaceCallout[i].transform( matrix );
+    for ( NormalizedPoint &np : m_transformedInplaceCallout ) {
+       np.transform( matrix );
     }
 }
 
@@ -1207,8 +1211,8 @@ void TextAnnotationPrivate::baseTransform( const QTransform &matrix )
 {
     AnnotationPrivate::baseTransform( matrix );
 
-    for ( int i = 0; i < 3; ++i ) {
-       m_inplaceCallout[i].transform( matrix );
+    for ( NormalizedPoint &np : m_inplaceCallout ) {
+       np.transform( matrix );
     }
 }
 
@@ -1328,7 +1332,7 @@ class Okular::LineAnnotationPrivate : public Okular::AnnotationPrivate
         void baseTransform( const QTransform &matrix ) override;
         void resetTransformation() override;
         void translate( const NormalizedPoint &coord ) override;
-        double distanceSqr( double x, double y, double xScale, double yScale ) override;
+        double distanceSqr( double x, double y, double xScale, double yScale ) const override;
         void setAnnotationProperties( const QDomNode& node ) override;
         AnnotationPrivate* getNewAnnotationPrivate() override;
 
@@ -1349,8 +1353,8 @@ LineAnnotation::LineAnnotation()
 {
 }
 
-LineAnnotation::LineAnnotation( const QDomNode & node )
-    : Annotation( *new LineAnnotationPrivate(), node )
+LineAnnotation::LineAnnotation( const QDomNode & description )
+    : Annotation( *new LineAnnotationPrivate(), description )
 {
 }
 
@@ -1619,7 +1623,7 @@ AnnotationPrivate* LineAnnotationPrivate::getNewAnnotationPrivate()
     return new LineAnnotationPrivate();
 }
 
-double LineAnnotationPrivate::distanceSqr( double x, double y, double xScale, double yScale )
+double LineAnnotationPrivate::distanceSqr( double x, double y, double xScale, double yScale ) const
 {
     QLinkedList<NormalizedPoint> transformedLinePoints = m_transformedLinePoints;
 
@@ -1629,7 +1633,7 @@ double LineAnnotationPrivate::distanceSqr( double x, double y, double xScale, do
     if ( m_lineInnerColor.isValid() )
     {
         QPolygonF polygon;
-        foreach ( const NormalizedPoint &p, transformedLinePoints )
+        for ( const NormalizedPoint &p : qAsConst(transformedLinePoints) )
             polygon.append( QPointF( p.x, p.y ) );
 
         if ( polygon.containsPoint( QPointF( x, y ), Qt::WindingFill ) )
@@ -1652,7 +1656,7 @@ class Okular::GeomAnnotationPrivate : public Okular::AnnotationPrivate
         void setAnnotationProperties( const QDomNode& node ) override;
         bool canBeResized() const override;
         AnnotationPrivate* getNewAnnotationPrivate() override;
-        double distanceSqr( double x, double y, double xScale, double yScale ) override;
+        double distanceSqr( double x, double y, double xScale, double yScale ) const override;
 
         GeomAnnotation::GeomType m_geomType;
         QColor m_geomInnerColor;
@@ -1663,8 +1667,8 @@ GeomAnnotation::GeomAnnotation()
 {
 }
 
-GeomAnnotation::GeomAnnotation( const QDomNode & node )
-    : Annotation( *new GeomAnnotationPrivate(), node )
+GeomAnnotation::GeomAnnotation( const QDomNode & description )
+    : Annotation( *new GeomAnnotationPrivate(), description )
 {
 }
 
@@ -1754,7 +1758,7 @@ AnnotationPrivate* GeomAnnotationPrivate::getNewAnnotationPrivate()
     return new GeomAnnotationPrivate();
 }
 
-double GeomAnnotationPrivate::distanceSqr( double x, double y, double xScale, double yScale )
+double GeomAnnotationPrivate::distanceSqr( double x, double y, double xScale, double yScale ) const
 {
     double distance = 0;
     //the line thickness is applied unevenly (only on the "inside") - account for this
@@ -1936,7 +1940,7 @@ class Okular::HighlightAnnotationPrivate : public Okular::AnnotationPrivate
 
         void transform( const QTransform &matrix ) override;
         void baseTransform( const QTransform &matrix ) override;
-        double distanceSqr( double x, double y, double xScale, double yScale ) override;
+        double distanceSqr( double x, double y, double xScale, double yScale ) const override;
         void setAnnotationProperties( const QDomNode& node ) override;
         AnnotationPrivate* getNewAnnotationPrivate() override;
 
@@ -1949,8 +1953,8 @@ HighlightAnnotation::HighlightAnnotation()
 {
 }
 
-HighlightAnnotation::HighlightAnnotation( const QDomNode & node )
-    : Annotation( *new HighlightAnnotationPrivate(), node )
+HighlightAnnotation::HighlightAnnotation( const QDomNode & description )
+    : Annotation( *new HighlightAnnotationPrivate(), description )
 {
 }
 
@@ -2087,11 +2091,11 @@ AnnotationPrivate* HighlightAnnotationPrivate::getNewAnnotationPrivate()
     return new HighlightAnnotationPrivate();
 }
 
-double HighlightAnnotationPrivate::distanceSqr( double x, double y, double xScale, double yScale )
+double HighlightAnnotationPrivate::distanceSqr( double x, double y, double xScale, double yScale ) const
 {
     NormalizedPoint point( x, y );
     double outsideDistance = DBL_MAX;
-    foreach ( const HighlightAnnotation::Quad& quad, m_highlightQuads )
+    for ( const HighlightAnnotation::Quad &quad : m_highlightQuads )
     {
         QLinkedList<NormalizedPoint> pathPoints;
 
@@ -2139,8 +2143,8 @@ StampAnnotation::StampAnnotation()
 {
 }
 
-StampAnnotation::StampAnnotation( const QDomNode & node )
-    : Annotation( *new StampAnnotationPrivate(), node )
+StampAnnotation::StampAnnotation( const QDomNode & description )
+    : Annotation( *new StampAnnotationPrivate(), description )
 {
 }
 
@@ -2225,7 +2229,7 @@ class Okular::InkAnnotationPrivate : public Okular::AnnotationPrivate
         void transform( const QTransform &matrix ) override;
         void baseTransform( const QTransform &matrix ) override;
         void resetTransformation() override;
-        double distanceSqr( double x, double y, double xScale, double yScale ) override;
+        double distanceSqr( double x, double y, double xScale, double yScale ) const override;
         void translate( const NormalizedPoint &coord ) override;
         void setAnnotationProperties( const QDomNode& node ) override;
         AnnotationPrivate* getNewAnnotationPrivate() override;
@@ -2239,8 +2243,8 @@ InkAnnotation::InkAnnotation()
 {
 }
 
-InkAnnotation::InkAnnotation( const QDomNode & node )
-    : Annotation( *new InkAnnotationPrivate(), node )
+InkAnnotation::InkAnnotation( const QDomNode & description )
+    : Annotation( *new InkAnnotationPrivate(), description )
 {
 }
 
@@ -2303,10 +2307,10 @@ void InkAnnotation::store( QDomNode & node, QDomDocument & document ) const
     }
 }
 
-double InkAnnotationPrivate::distanceSqr( double x, double y, double xScale, double yScale )
+double InkAnnotationPrivate::distanceSqr( double x, double y, double xScale, double yScale ) const
 {
     double distance = DBL_MAX;
-    foreach ( const QLinkedList<NormalizedPoint>& path, m_transformedInkPaths )
+    for ( const QLinkedList<NormalizedPoint> &path : m_transformedInkPaths )
     {
         const double thisDistance = ::distanceSqr( x, y, xScale, yScale, path );
         if ( thisDistance < distance )
@@ -2489,8 +2493,8 @@ CaretAnnotation::CaretAnnotation()
 {
 }
 
-CaretAnnotation::CaretAnnotation( const QDomNode & node )
-    : Annotation( *new CaretAnnotationPrivate(), node )
+CaretAnnotation::CaretAnnotation( const QDomNode & description )
+    : Annotation( *new CaretAnnotationPrivate(), description )
 {
 }
 
@@ -2580,8 +2584,8 @@ FileAttachmentAnnotation::FileAttachmentAnnotation()
 {
 }
 
-FileAttachmentAnnotation::FileAttachmentAnnotation( const QDomNode & node )
-    : Annotation( *new FileAttachmentAnnotationPrivate(), node )
+FileAttachmentAnnotation::FileAttachmentAnnotation( const QDomNode & description )
+    : Annotation( *new FileAttachmentAnnotationPrivate(), description )
 {
 }
 
@@ -2610,10 +2614,10 @@ QString FileAttachmentAnnotation::fileIconName() const
     return d->icon;
 }
 
-void FileAttachmentAnnotation::setFileIconName( const QString &icon )
+void FileAttachmentAnnotation::setFileIconName( const QString &iconName )
 {
     Q_D( FileAttachmentAnnotation );
-    d->icon = icon;
+    d->icon = iconName;
 }
 
 EmbeddedFile* FileAttachmentAnnotation::embeddedFile() const
@@ -2679,8 +2683,8 @@ SoundAnnotation::SoundAnnotation()
 {
 }
 
-SoundAnnotation::SoundAnnotation( const QDomNode & node )
-    : Annotation( *new SoundAnnotationPrivate(), node )
+SoundAnnotation::SoundAnnotation( const QDomNode & description )
+    : Annotation( *new SoundAnnotationPrivate(), description )
 {
 }
 
@@ -2709,10 +2713,10 @@ QString SoundAnnotation::soundIconName() const
     return d->icon;
 }
 
-void SoundAnnotation::setSoundIconName( const QString &icon )
+void SoundAnnotation::setSoundIconName( const QString &iconName )
 {
     Q_D( SoundAnnotation );
-    d->icon = icon;
+    d->icon = iconName;
 }
 
 Sound* SoundAnnotation::sound() const
@@ -2776,8 +2780,8 @@ MovieAnnotation::MovieAnnotation()
 {
 }
 
-MovieAnnotation::MovieAnnotation( const QDomNode & node )
-    : Annotation( *new MovieAnnotationPrivate(), node )
+MovieAnnotation::MovieAnnotation( const QDomNode & description )
+    : Annotation( *new MovieAnnotationPrivate(), description )
 {
 }
 
@@ -2866,8 +2870,8 @@ ScreenAnnotation::ScreenAnnotation()
 {
 }
 
-ScreenAnnotation::ScreenAnnotation( const QDomNode & node )
-    : Annotation( *new ScreenAnnotationPrivate(), node )
+ScreenAnnotation::ScreenAnnotation( const QDomNode & description )
+    : Annotation( *new ScreenAnnotationPrivate(), description )
 {
 }
 
@@ -2967,8 +2971,8 @@ WidgetAnnotation::WidgetAnnotation()
 {
 }
 
-WidgetAnnotation::WidgetAnnotation( const QDomNode & node )
-    : Annotation( *new WidgetAnnotationPrivate, node )
+WidgetAnnotation::WidgetAnnotation( const QDomNode & description )
+    : Annotation( *new WidgetAnnotationPrivate, description )
 {
 }
 
@@ -3063,8 +3067,8 @@ RichMediaAnnotation::RichMediaAnnotation()
 {
 }
 
-RichMediaAnnotation::RichMediaAnnotation( const QDomNode & node )
-    : Annotation( *new RichMediaAnnotationPrivate, node )
+RichMediaAnnotation::RichMediaAnnotation( const QDomNode & description )
+    : Annotation( *new RichMediaAnnotationPrivate, description )
 {
 }
 
