@@ -716,11 +716,16 @@ class OKULARCORE_EXPORT AnnotationProxy
             Removal         ///< Generator can remove native annotations
         };
 
+        AnnotationProxy();
+
         /**
          * Destroys the annotation proxy.
          */
         virtual ~AnnotationProxy();
 
+        AnnotationProxy(const AnnotationProxy &) = delete;
+        AnnotationProxy &operator=(const AnnotationProxy &) = delete;
+
         /**
          * Query for the supported capabilities.
          */
@@ -786,7 +791,7 @@ class OKULARCORE_EXPORT TextAnnotation : public Annotation
         /**
          * Destroys the text annotation.
          */
-        ~TextAnnotation();
+        ~TextAnnotation() override;
 
         /**
          * Sets the text @p type of the text annotation.
@@ -934,7 +939,7 @@ class OKULARCORE_EXPORT LineAnnotation : public Annotation
         /**
          * Destroys the line annotation.
          */
-        ~LineAnnotation();
+        ~LineAnnotation() override;
 
         /**
          * Sets the normalized line @p points of the line annotation.
@@ -1073,7 +1078,7 @@ class OKULARCORE_EXPORT GeomAnnotation : public Annotation
         /**
          * Destroys the geometrical annotation.
          */
-        ~GeomAnnotation();
+        ~GeomAnnotation() override;
 
         /**
          * Sets the geometrical @p type of the geometrical annotation.
@@ -1139,7 +1144,7 @@ class OKULARCORE_EXPORT HighlightAnnotation : public Annotation
         /**
          * Destroys the highlight annotation.
          */
-        ~HighlightAnnotation();
+        ~HighlightAnnotation() override;
 
         /**
          * Sets the @p type of the highlight annotation.
@@ -1153,8 +1158,18 @@ class OKULARCORE_EXPORT HighlightAnnotation : public Annotation
         HighlightType highlightType() const;
 
         /**
-         * The Quad class contains 8 coordinates and style definitions
-         * which describe a line part of the whole highlight annotation.
+         * @short Describes a highlight quad of a text markup annotation.
+         *
+         * The Quad is a closed path of 4 NormalizedPoints.
+         * Another set of 4 NormalizedPoints can be generated with transform(),
+         * e. g. to get highlighting coordinates on a rotated PageViewItem.
+         * Additionally, Quad stores some geometry related style attributes.
+         *
+         * To enable correct rendering of the annotation,
+         * the points 0 and 1 must describe the bottom edge of the quad
+         * (relative to the text orientation).
+         *
+         * @see NormalizedPoint
          */
         class OKULARCORE_EXPORT Quad
         {
@@ -1226,6 +1241,9 @@ class OKULARCORE_EXPORT HighlightAnnotation : public Annotation
                 /**
                  * Transforms the quad coordinates with the transformation defined
                  * by @p matrix.
+                 *
+                 * The transformed coordinates will be accessible with transformedPoint().
+                 * The coordinates returned by point() are not affected.
                  */
                 void transform( const QTransform &matrix );
 
@@ -1271,7 +1289,7 @@ class OKULARCORE_EXPORT StampAnnotation : public Annotation
         /**
          * Destroys the stamp annotation.
          */
-        ~StampAnnotation();
+        ~StampAnnotation() override;
 
         /**
          * Sets the @p name of the icon for the stamp annotation.
@@ -1315,7 +1333,7 @@ class OKULARCORE_EXPORT InkAnnotation : public Annotation
         /**
          * Destroys the ink annotation.
          */
-        ~InkAnnotation();
+        ~InkAnnotation() override;
 
         /**
          * Sets the @p paths of points for the ink annotation.
@@ -1374,7 +1392,7 @@ class OKULARCORE_EXPORT CaretAnnotation : public Annotation
         /**
          * Destroys the caret annotation.
          */
-        ~CaretAnnotation();
+        ~CaretAnnotation() override;
 
         /**
          * Sets the @p symbol for the caret annotation.
@@ -1416,7 +1434,7 @@ class OKULARCORE_EXPORT FileAttachmentAnnotation : public Annotation
         /**
          * Destroys the file attachment annotation.
          */
-        virtual ~FileAttachmentAnnotation();
+        ~FileAttachmentAnnotation() override;
 
         /**
          * Gets the name of the icon.
@@ -1424,9 +1442,9 @@ class OKULARCORE_EXPORT FileAttachmentAnnotation : public Annotation
         QString fileIconName() const;
 
         /**
-         * Sets the @p name of the icon for the file attachment annotation.
+         * Sets the @p iconName of the icon for the file attachment annotation.
          */
-        void setFileIconName( const QString &name );
+        void setFileIconName( const QString &iconName );
 
         /**
          * Gets the embedded file object.
@@ -1434,10 +1452,10 @@ class OKULARCORE_EXPORT FileAttachmentAnnotation : public Annotation
         EmbeddedFile* embeddedFile() const;
 
         /**
-         * Sets the @p object representing the embedded file of the file
+         * Sets the @p ef representing the embedded file of the file
          * attachment annotation.
          */
-        void setEmbeddedFile( EmbeddedFile *object );
+        void setEmbeddedFile( EmbeddedFile *ef );
 
         /**
          * Returns the sub type of the file attachment annotation.
@@ -1476,7 +1494,7 @@ class OKULARCORE_EXPORT SoundAnnotation : public Annotation
         /**
          * Destroys the sound annotation.
          */
-        virtual ~SoundAnnotation();
+        ~SoundAnnotation() override;
 
         /**
          * Gets the name of the icon.
@@ -1484,9 +1502,9 @@ class OKULARCORE_EXPORT SoundAnnotation : public Annotation
         QString soundIconName() const;
 
         /**
-         * Sets the @p name of the icon for the sound annotation.
+         * Sets the @p iconName of the icon for the sound annotation.
          */
-        void setSoundIconName( const QString &name );
+        void setSoundIconName( const QString &iconName );
 
         /**
          * Gets the sound object.
@@ -1494,10 +1512,10 @@ class OKULARCORE_EXPORT SoundAnnotation : public Annotation
         Sound* sound() const;
 
         /**
-         * Sets the @p object representing the sound of the file
+         * Sets the @p s representing the sound of the file
          * attachment annotation.
          */
-        void setSound( Sound *object );
+        void setSound( Sound *s );
 
         /**
          * Returns the sub type of the sound annotation.
@@ -1536,7 +1554,7 @@ class OKULARCORE_EXPORT MovieAnnotation : public Annotation
         /**
          * Destroys the movie annotation.
          */
-        virtual ~MovieAnnotation();
+        ~MovieAnnotation() override;
         /**
          * Gets the movie object.
          */
@@ -1584,7 +1602,7 @@ class OKULARCORE_EXPORT ScreenAnnotation : public Annotation
         /**
          * Destroys the screen annotation.
          */
-        virtual ~ScreenAnnotation();
+        ~ScreenAnnotation() override;
 
         /**
          * Returns the sub type of the screen annotation.
@@ -1653,7 +1671,7 @@ class OKULARCORE_EXPORT WidgetAnnotation : public Annotation
         /**
          * Destroys the widget annotation.
          */
-        virtual ~WidgetAnnotation();
+        ~WidgetAnnotation() override;
 
         /**
          * Returns the sub type of the widget annotation.
@@ -1708,7 +1726,7 @@ class OKULARCORE_EXPORT RichMediaAnnotation : public Annotation
         /**
          * Destroys the rich media annotation.
          */
-        virtual ~RichMediaAnnotation();
+        ~RichMediaAnnotation() override;
 
         /**
          * Returns the sub type of the rich media annotation.
@@ -1732,9 +1750,9 @@ class OKULARCORE_EXPORT RichMediaAnnotation : public Annotation
         void setMovie( Movie *movie );
 
         /**
-         * Sets the @p object representing the embedded file.
+         * Sets the @p embeddedFile representing the embedded file.
          */
-        void setEmbeddedFile( EmbeddedFile *object );
+        void setEmbeddedFile( EmbeddedFile *embeddedFile );
 
         /**
          * Gets the embedded file object.
