@@ -68,8 +68,9 @@ struct GeneratorInfo
 
 namespace Okular {
 
-class BackendConfigDialog : public KConfigDialog
+class OKULARCORE_EXPORT BackendConfigDialog : public KConfigDialog
 {
+    Q_OBJECT
 public:
     BackendConfigDialog(QWidget *parent, const QString &name, KCoreConfigSkeleton *config)
      : KConfigDialog(parent, name, config)
@@ -136,7 +137,7 @@ class DocumentPrivate
         bool updateMetadataXmlNameAndDocSize();
         QString pagesSizeString() const;
         QString namePaperSize(double inchesWidth, double inchesHeight) const;
-        QString localizedSize(const QSizeF &size) const;
+        QString localizedSize(const QSizeF size) const;
         qulonglong calculateMemoryToFree();
         void cleanupPixmapMemory();
         void cleanupPixmapMemory( qulonglong memoryToFree );
@@ -185,7 +186,7 @@ class DocumentPrivate
         void rotationFinished( int page, Okular::Page *okularPage );
         void slotFontReadingProgress( int page );
         void fontReadingGotFont( const Okular::FontInfo& font );
-        void slotGeneratorConfigChanged( const QString& );
+        void slotGeneratorConfigChanged();
         void refreshPixmaps( int );
         void _o_configChanged();
         void doContinueDirectionMatchSearch(void *doContinueDirectionMatchSearchStruct);
@@ -339,6 +340,8 @@ class DocumentPrivate
 
         synctex_scanner_p m_synctex_scanner;
 
+        QString m_openError;
+
         // generator selection
         static QVector<KPluginMetaData> availableGenerators();
         static QVector<KPluginMetaData> configurableGenerators();
