@@ -37,7 +37,7 @@ class SearchDataKeeper
 		{
 			m_inPhrase = false;
 			phrasewords += phrase_terms;
-			phrases.push_back( phrase_terms.join(" ") );
+			phrases.push_back( phrase_terms.join(QStringLiteral(" ")) );
 		}
 
 		bool isInPhrase() const { return m_inPhrase; }
@@ -71,7 +71,7 @@ class SearchDataKeeper
 
 EBookSearch::EBookSearch()
 {
-	m_Index = 0;
+	m_Index = nullptr;
 }
 
 
@@ -95,7 +95,7 @@ bool EBookSearch::generateIndex( EBook * ebookFile, QDataStream & stream )
 	QList< QUrl > documents;
 	QList< QUrl > alldocuments;
 	
-	emit progressStep( 0, "Generating the list of documents" );
+	emit progressStep( 0, QStringLiteral("Generating the list of documents") );
 	processEvents();
 
 	// Enumerate the documents
@@ -106,23 +106,23 @@ bool EBookSearch::generateIndex( EBook * ebookFile, QDataStream & stream )
 		delete m_Index;
 
 	m_Index = new QtAs::Index();
-	connect( m_Index, SIGNAL( indexingProgress( int, const QString& ) ), this, SLOT( updateProgress( int, const QString& ) ) );
+	connect( m_Index, &QtAs::Index::indexingProgress, this, &EBookSearch::updateProgress );
 	
 	// Process the list of files in CHM archive and keep only HTML document files from there
-	for ( int i = 0; i < alldocuments.size(); i++ )
+	for ( const QUrl &allDocumentsI : qAsConst( alldocuments ) )
 	{
-		QString docpath = alldocuments[i].path();
+		const QString docpath = allDocumentsI.path();
 
-		if ( docpath.endsWith( ".html", Qt::CaseInsensitive )
-		|| docpath.endsWith( ".htm", Qt::CaseInsensitive )
-		|| docpath.endsWith( ".xhtml", Qt::CaseInsensitive ) )
-			documents.push_back( alldocuments[i] );
+		if ( docpath.endsWith( QLatin1String(".html"), Qt::CaseInsensitive )
+		|| docpath.endsWith( QLatin1String(".htm"), Qt::CaseInsensitive )
+		|| docpath.endsWith( QLatin1String(".xhtml"), Qt::CaseInsensitive ) )
+			documents.push_back( allDocumentsI );
 	}
 
     if ( !m_Index->makeIndex( documents, ebookFile ) )
 	{
 		delete m_Index;
-		m_Index = 0;
+		m_Index = nullptr;
 		return false;
 	}
 	
@@ -167,9 +167,9 @@ bool EBookSearch::searchQuery(const QString & query, QList< QUrl > * results, EB
 	SearchDataKeeper keeper;	
 	QString term;
 
-	for ( int i = 0; i < query.length(); i++ )
+	for ( const QChar &iChar : query )
 	{
-		QChar ch = query[i].toLower();
+		const QChar ch = iChar.toLower();
 		
 		// a quote either begins or ends the phrase
 		if ( ch == '"' )
@@ -221,5 +221,5 @@ bool EBookSearch::searchQuery(const QString & query, QList< QUrl > * results, EB
 
 bool EBookSearch::hasIndex() const
 {
-	return m_Index != 0;
+	return m_Index != nullptr;
 }
