@@ -35,12 +35,13 @@ using namespace ComicBook;
 
 static void imagesInArchive( const QString &prefix, const KArchiveDirectory* dir, QStringList *entries )
 {
-    Q_FOREACH ( const QString &entry, dir->entries() ) {
-        const KArchiveEntry *e = dir->entry( entry );
+    const QStringList entryList =  dir->entries();
+    for ( const QString &file : entryList ) {
+        const KArchiveEntry *e = dir->entry( file );
         if ( e->isDirectory() ) {
-            imagesInArchive( prefix + entry + QLatin1Char('/'), static_cast<const KArchiveDirectory*>( e ), entries );
+            imagesInArchive( prefix + file + QLatin1Char('/'), static_cast<const KArchiveDirectory*>( e ), entries );
         } else if ( e->isFile() ) {
-            entries->append( prefix + entry );
+            entries->append( prefix + file );
         }
     }
 }
@@ -184,7 +185,8 @@ void Document::pages( QVector<Okular::Page*> * pagesVector )
     pagesVector->clear();
     pagesVector->resize( mEntries.size() );
     QImageReader reader;
-    foreach(const QString &file, mEntries) {
+    reader.setAutoTransform( true );
+    for (const QString &file : qAsConst(mEntries)) {
         if ( mArchive ) {
             const KArchiveFile *entry = static_cast<const KArchiveFile*>( mArchiveDir->entry( file ) );
             if ( entry ) {
@@ -201,6 +203,9 @@ void Document::pages( QVector<Okular::Page*> * pagesVector )
             if ( reader.canRead() )
             {
                 QSize pageSize = reader.size();
+                if (reader.transformation() & QImageIOHandler::TransformationRotate90) {
+                    pageSize.transpose();
+                }
                 if ( !pageSize.isValid() ) {
                     const QImage i = reader.read();
                     if ( !i.isNull() )
@@ -228,8 +233,12 @@ QImage Document::pageImage( int page ) const
 {
     if ( mArchive ) {
         const KArchiveFile *entry = static_cast<const KArchiveFile*>( mArchiveDir->entry( mPageMap[ page ] ) );
-        if ( entry )
-            return QImage::fromData( entry->data() );
+        if ( entry ) {
+            std::unique_ptr<QIODevice> dev(entry->createDevice());
+            QImageReader reader( dev.get() );
+            reader.setAutoTransform( true );
+            return reader.read();
+        }
     } else if ( mDirectory ) {
         return QImage( mPageMap[ page ] );
     } else {
@@ -244,3 +253,4 @@ QString Document::lastErrorString() const
     return mLastErrorString;
 }
 
+Q_LOGGING_CATEGORY(OkularComicbookDebug, "org.kde.okular.generators.comicbook", QtWarningMsg)
