@@ -26,7 +26,7 @@
 
 #include <stdio.h>
 
-QDebug &operator<<( QDebug & s, const ddjvu_rect_t &r )
+QDebug &operator<<( QDebug & s, const ddjvu_rect_t r )
 {
     s.nospace() << "[" << r.x << "," << r.y << " - " << r.w << "x" << r.h << "]";
     return s.space();
@@ -1057,7 +1057,7 @@ bool KDjVu::exportAsPostScript( QFile* file, const QList<int>& pageList ) const
     }
 
     QString pl;
-    foreach ( int p, pageList )
+    for ( const int p : pageList )
     {
         if ( !pl.isEmpty() )
             pl += QLatin1String( "," );
