@@ -23,10 +23,13 @@ class TeXFont {
 
   virtual ~TeXFont();
 
+  TeXFont(const TeXFont &) = delete;
+  TeXFont &operator=(const TeXFont &) = delete;
+
   void setDisplayResolution()
     {
-      for(unsigned int i=0; i<TeXFontDefinition::max_num_of_chars_in_font; i++)
-        glyphtable[i].shrunkenCharacter = QImage();
+      for(glyph &g : glyphtable)
+        g.shrunkenCharacter = QImage();
     }
 
   virtual glyph* getGlyph(quint16 character, bool generateCharacterPixmap=false, const QColor& color=Qt::black) = 0;
