@@ -117,13 +117,13 @@ bool DviGenerator::doCloseDocument()
 }
 
 void DviGenerator::fillViewportFromAnchor( Okular::DocumentViewport &vp,
-                                           const Anchor &anch, const Okular::Page *page ) const
+                                           const Anchor anch, const Okular::Page *page ) const
 {
     fillViewportFromAnchor( vp, anch, page->width(), page->height() );
 }
 
 void DviGenerator::fillViewportFromAnchor( Okular::DocumentViewport &vp,
-                                           const Anchor &anch, int pW, int pH ) const
+                                           const Anchor anch, int pW, int pH ) const
 {
     vp.pageNumber = anch.page - 1;
 
@@ -147,7 +147,7 @@ QLinkedList<Okular::ObjectRect*> DviGenerator::generateDviLinks( const dviPageIn
 
     int pageWidth = pageInfo->width, pageHeight = pageInfo->height;
     
-    foreach( const Hyperlink &dviLink, pageInfo->hyperLinkList )
+    for ( const Hyperlink &dviLink : qAsConst(pageInfo->hyperLinkList) )
     {
         QRect boxArea = dviLink.box;
         double nl = (double)boxArea.left() / pageWidth,
@@ -212,17 +212,12 @@ QImage DviGenerator::image( Okular::PixmapRequest *request )
 
         if (s.isValid())
         {
-            ps = s; /* it should be the user specified size, if any, instead */
+            pageInfo->resolution = (double)(pageInfo->width)/s.width().getLength_in_inch();
+        }
+        else
+        {
+            pageInfo->resolution = (double)(pageInfo->width)/ps.width().getLength_in_inch();
         }
-
-        pageInfo->resolution = (double)(pageInfo->width)/ps.width().getLength_in_inch();
-
-#if 0
-        qCDebug(OkularDviDebug) << *request
-        << ", res:" << pageInfo->resolution << " - (" << pageInfo->width << ","
-        << ps.width().getLength_in_inch() << ")," << ps.width().getLength_in_mm()
-        << endl;
-#endif
 
         m_dviRenderer->drawPage( pageInfo );
 
@@ -391,9 +386,8 @@ Okular::FontInfo::List DviGenerator::fontsForPage( int page )
     if ( m_dviRenderer && m_dviRenderer->dviFile &&
          m_dviRenderer->dviFile->font_pool )
     {
-        QList<TeXFontDefinition*> fonts = m_dviRenderer->dviFile->font_pool->fontList;
-
-        foreach (const TeXFontDefinition* font, fonts)
+        const QList<TeXFontDefinition *> fonts = m_dviRenderer->dviFile->font_pool->fontList;
+        for (const TeXFontDefinition *font : fonts)
         {
             Okular::FontInfo of;
             QString name;
@@ -506,7 +500,7 @@ void DviGenerator::loadPages( QVector< Okular::Page * > &pagesVector )
     // filling the pages with the source references rects
     const QVector<DVI_SourceFileAnchor>& sourceAnchors = m_dviRenderer->sourceAnchors();
     QVector< QLinkedList< Okular::SourceRefObjectRect * > > refRects( numofpages );
-    foreach ( const DVI_SourceFileAnchor& sfa, sourceAnchors )
+    for ( const DVI_SourceFileAnchor &sfa : sourceAnchors )
     {
         if ( sfa.page < 1 || (int)sfa.page > numofpages )
             continue;
@@ -527,14 +521,14 @@ bool DviGenerator::print( QPrinter& printer )
     if ( !tf.open() )
         return false;
 
-    QList<int> pageList = Okular::FilePrinter::pageList( printer, 
+    const QList<int> pageList = Okular::FilePrinter::pageList( printer, 
                                  m_dviRenderer->totalPages(),
                                  document()->currentPage() + 1,
                                  document()->bookmarkedPageList() );
     QString pages;
     QStringList printOptions;
     // List of pages to print.
-    foreach ( int p, pageList )
+    for ( const int p : pageList )
     {
         pages += QStringLiteral(",%1").arg(p);
     }
