@@ -32,9 +32,7 @@ Q_DECLARE_METATYPE( Poppler::Annotation* )
 extern Okular::Sound* createSoundFromPopplerSound( const Poppler::SoundObject *popplerSound );
 extern Okular::Movie* createMovieFromPopplerMovie( const Poppler::MovieObject *popplerMovie );
 extern Okular::Movie* createMovieFromPopplerScreen( const Poppler::LinkRendition *popplerScreen );
-#ifdef HAVE_POPPLER_0_36
 extern QPair<Okular::Movie*, Okular::EmbeddedFile*> createMovieFromPopplerRichMedia( const Poppler::RichMediaAnnotation *popplerRichMedia );
-#endif
 
 
 static void disposeAnnotation( const Okular::Annotation *ann )
@@ -193,8 +191,11 @@ void PopplerAnnotationProxy::notifyModification( const Okular::Annotation *okl_a
             const Okular::LineAnnotation * okl_lineann = static_cast<const Okular::LineAnnotation*>(okl_ann);
             Poppler::LineAnnotation * ppl_lineann = static_cast<Poppler::LineAnnotation*>(ppl_ann);
             QLinkedList<QPointF> points;
-            foreach ( const Okular::NormalizedPoint &p, okl_lineann->linePoints() )
+            const QLinkedList<Okular::NormalizedPoint> annotPoints = okl_lineann->linePoints();
+            for ( const Okular::NormalizedPoint &p : annotPoints  )
+            {
                 points.append(normPointToPointF( p ));
+            }
             ppl_lineann->setLinePoints( points );
             ppl_lineann->setLineStartStyle( (Poppler::LineAnnotation::TermStyle)okl_lineann->lineStartStyle() );
             ppl_lineann->setLineEndStyle( (Poppler::LineAnnotation::TermStyle)okl_lineann->lineEndStyle() );
@@ -233,11 +234,14 @@ void PopplerAnnotationProxy::notifyModification( const Okular::Annotation *okl_a
             const Okular::InkAnnotation * okl_inkann = static_cast<const Okular::InkAnnotation*>(okl_ann);
             Poppler::InkAnnotation * ppl_inkann = static_cast<Poppler::InkAnnotation*>(ppl_ann);
             QList< QLinkedList<QPointF> > paths;
-            foreach ( const QLinkedList<Okular::NormalizedPoint> &path, okl_inkann->inkPaths() )
+            const QList< QLinkedList<Okular::NormalizedPoint> > inkPathsList = okl_inkann->inkPaths();
+            for ( const QLinkedList<Okular::NormalizedPoint> &path : inkPathsList )
             {
                 QLinkedList<QPointF> points;
-                foreach ( const Okular::NormalizedPoint &p, path )
+                for ( const Okular::NormalizedPoint &p : path )
+                {
                     points.append(normPointToPointF( p ));
+                }
                 paths.append( points );
             }
             ppl_inkann->setInkPaths( paths );
@@ -273,7 +277,7 @@ void PopplerAnnotationProxy::notifyRemoval( Okular::Annotation *okl_ann, int pag
 
 Okular::Annotation* createAnnotationFromPopplerAnnotation( Poppler::Annotation *ann, bool *doDelete )
 {
-    Okular::Annotation *annotation = 0;
+    Okular::Annotation *annotation = nullptr;
     *doDelete = true;
     bool tieToOkularAnn = false;
     bool externallyDrawn = false;
@@ -328,7 +332,6 @@ Okular::Annotation* createAnnotationFromPopplerAnnotation( Poppler::Annotation *
             *doDelete = false;
             break;
         }
-#ifdef HAVE_POPPLER_0_36
         case Poppler::Annotation::ARichMedia:
         {
             Poppler::RichMediaAnnotation * richmediaann = static_cast< Poppler::RichMediaAnnotation * >( ann );
@@ -346,7 +349,6 @@ Okular::Annotation* createAnnotationFromPopplerAnnotation( Poppler::Annotation *
 
             break;
         }
-#endif
         case Poppler::Annotation::AText:
         case Poppler::Annotation::ALine:
         case Poppler::Annotation::AGeom:
@@ -391,16 +393,14 @@ Okular::Annotation* createAnnotationFromPopplerAnnotation( Poppler::Annotation *
         if ( annotation->subType() == Okular::Annotation::AHighlight )
         {
             Okular::HighlightAnnotation * hlann = static_cast<Okular::HighlightAnnotation*>( annotation );
-            QList<Okular::HighlightAnnotation::Quad> &quads = hlann->highlightQuads();
-            for (QList<Okular::HighlightAnnotation::Quad>::iterator it = quads.begin(); it != quads.end(); ++it)
+            for (Okular::HighlightAnnotation::Quad &quad : hlann->highlightQuads())
             {
-                Okular::NormalizedPoint t;
-                t = it->point( 3 );
-                it->setPoint( it->point(0), 3 );
-                it->setPoint( t, 0 );
-                t = it->point( 2 );
-                it->setPoint( it->point(1), 2 );
-                it->setPoint( t, 1 );
+                const Okular::NormalizedPoint p3 = quad.point( 3 );
+                quad.setPoint( quad.point(0), 3 );
+                quad.setPoint( p3, 0 );
+                const Okular::NormalizedPoint p2 = quad.point( 2 );
+                quad.setPoint( quad.point(1), 2 );
+                quad.setPoint( p2, 1 );
             }
         }
 
