@@ -22,7 +22,7 @@ class PopplerCertificateInfo : public Okular::CertificateInfo
 {
     public:
         PopplerCertificateInfo(const Poppler::CertificateInfo &info);
-        ~PopplerCertificateInfo();
+        ~PopplerCertificateInfo() override;
 
         bool isNull() const override;
         int version() const override;
@@ -44,13 +44,11 @@ class PopplerCertificateInfo : public Okular::CertificateInfo
 
 #endif
 
-#ifdef HAVE_POPPLER_0_51
-
 class PopplerSignatureInfo : public Okular::SignatureInfo
 {
     public:
         PopplerSignatureInfo( const Poppler::SignatureValidationInfo &info );
-        ~PopplerSignatureInfo();
+        ~PopplerSignatureInfo() override;
 
         SignatureStatus signatureStatus() const override;
         CertificateStatus certificateStatus() const override;
@@ -71,5 +69,3 @@ class PopplerSignatureInfo : public Okular::SignatureInfo
 };
 
 #endif
-
-#endif
