@@ -22,6 +22,7 @@
 #include "documentitem.h"
 #include "pageitem.h"
 #include "thumbnailitem.h"
+#include "okularsingleton.h"
 
 #include <QQmlEngine>
 #include <QPluginLoader>
@@ -36,6 +37,7 @@ void OkularPlugin::registerTypes(const char *uri)
     if (QString::fromLocal8Bit(uri) != QLatin1String("org.kde.okular")) {
         return;
     }
+    qmlRegisterSingletonType<OkularSingleton>(uri, 2, 0, "Okular", [] (QQmlEngine*, QJSEngine*) -> QObject* { return new OkularSingleton; });
     qmlRegisterType<DocumentItem>(uri, 2, 0, "DocumentItem");
     qmlRegisterType<PageItem>(uri, 2, 0, "PageItem");
     qmlRegisterType<ThumbnailItem>(uri, 2, 0, "ThumbnailItem");
