@@ -21,6 +21,7 @@
 #include <QMimeType>
 #include <QMimeDatabase>
 #include <QAction>
+#include <QList>
 
 #include <QtDBus> // krazy:exclude=includes
 
@@ -29,8 +30,6 @@ class KToggleAction;
 class QTabWidget;
 class KPluginFactory;
 
-class Part;
-
 #ifndef Q_OS_WIN
 namespace KActivities { class ResourceInstance; }
 #endif
@@ -59,7 +58,7 @@ public:
   /**
    * Default Destructor
    */
-  virtual ~Shell();
+  ~Shell() override;
 
   QSize sizeHint() const override;
 
@@ -126,9 +125,10 @@ private Q_SLOTS:
   void closeTab( int tab );
   void activateNextTab();
   void activatePrevTab();
+  void undoCloseTab();
   void moveTabData( int from, int to );
 
-  void slotFitWindowToPage( const QSize& pageViewSize, const QSize& pageSize );
+  void slotFitWindowToPage( const QSize pageViewSize, const QSize pageSize );
 
 Q_SIGNALS:
   void moveSplitter(int sideWidgetSize);
@@ -170,8 +170,10 @@ private:
     bool closeEnabled;
   };
   QList<TabState> m_tabs;
+  QList<QUrl> m_closedTabUrls;
   QAction* m_nextTabAction;
   QAction* m_prevTabAction;
+  QAction* m_undoCloseTab;
 
 #ifndef Q_OS_WIN
   KActivities::ResourceInstance* m_activityResource;
