@@ -29,11 +29,11 @@ Q_OBJECT
 		EmbeddedFilesDialog(QWidget *parent, const Okular::Document *document);
 
     private Q_SLOTS:
-		void saveFile();
-		void attachViewContextMenu( const QPoint& pos );
+		void saveFileFromButton();
+		void attachViewContextMenu();
 		void updateSaveButton();
-		void viewFile();
-		void viewFileItem( QTreeWidgetItem* index, int column );
+		void viewFileFromButton();
+		void viewFileItem( QTreeWidgetItem* item, int column );
 
 	private:
 		void saveFile( Okular::EmbeddedFile* );
